==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.2/sql/wzeiten.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP procedure IF EXISTS wzeiten//
create procedure wzeiten(wid integer, sid integer, sec integer, tst integer,
                         det integer, aid integer, dt date)
  deterministic
  sql security invoker
 begin
  declare fd, ld date;

  set fd = NULL;
  set ld = '0000-00-00';
  select fdate, ldate from wertedates
    where werteindizesID = wid and fdate <= dt and dt - interval 1 day <= ldate
      order by fdate, ldate desc
      limit 1
    into fd, ld;
  if ld < dt then
    if fd is NULL then
      insert ignore into wertedates
        (werteindizesID, serverID, sectionID, teststepID, teststepdetailsID, accessID, fdate, ldate)
        values (wid, sid, sec, tst, det, aid, dt, dt); 
    else
      update wertedates set ldate = dt
        where werteindizesID = wid and fdate = fd and ldate <= dt;
    end if;
    set fd = NULL;
    set ld = '0000-00-00';
    select fdate, ldate from teststepdates
        where serverID = sid and sectionID = sec and teststepID = tst and accessID = aid
          and fdate <= dt and dt - interval 1 day <= ldate
        order by fdate, ldate desc
        limit 1
      into fd, ld;
    if ld < dt then
      if fd is NULL then
        insert ignore into teststepdates
          (serverID, sectionID, teststepID, accessID, fdate, ldate)
          values (sid, sec, tst, aid, dt, dt);
      else
        update teststepdates set ldate = dt
          where serverID = sid and sectionID = sec and teststepID = tst and accessID = aid
            and fdate = fd and ldate <= dt;
      end if;
      set fd = NULL;
      set ld = '0000-00-00';
      select fdate, ldate from sectiondates
          where serverID = sid and sectionID = sec and accessID = aid
            and fdate <= dt and dt - interval 1 day <= ldate
          order by fdate, ldate desc
          limit 1
        into fd, ld;
      if ld < dt then
        if fd is NULL then
          insert ignore into sectiondates (serverID, sectionID, accessID, fdate, ldate)
            values (sid, sec, aid, dt, dt);
        else
          update sectiondates set ldate = dt
            where serverID = sid and sectionID = sec and accessID = aid
              and fdate = fd and ldate <= dt;
        end if;
        set fd = NULL;
        set ld = '0000-00-00';
        select fdate, ldate from serverdates
            where serverID = sid and accessID = aid
              and fdate <= dt and dt - interval 1 day <= ldate
            order by fdate, ldate desc
            limit 1
          into fd, ld;
        if ld < dt then
          if fd is NULL then
            insert ignore into serverdates (serverID, accessID, fdate, ldate)
            values (sid, aid, dt, dt);
          else
            update serverdates set ldate = dt
              where serverID = sid and accessID = aid
                and fdate = fd and ldate <= dt;
          end if;
        end if;
      end if;
    end if;
  end if;
end//

GRANT EXECUTE on PROCEDURE wzeiten to logging@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/wzeiten.sql <==
-- wzeiten.sql
--
-- procedure wzeiten(wid, sid, sec, tst, det, aid, dt)
-- wid: werteindizesID
-- sid: serverID
-- sec: sectionID
-- tst: teststepID
-- det: teststepdetailsID
-- aid: accessID
-- dt: datetime
--
-- add entry in table wertedates, teststepdates, sectiondates, serverdates if not exists

set @@character_set_client = 'utf8';

delimiter //

DROP procedure IF EXISTS wzeiten//
create procedure wzeiten(wid integer, sid integer, sec integer, tst integer,
                         det integer, aid integer, dt date)
  deterministic
  sql security invoker
 begin
  declare fd, ld date;

  set fd = NULL;
  set ld = '0000-00-00';
  select fdate, ldate into fd, ld from wertedates
    where werteindizesID = wid and fdate <= dt and dt - interval 1 day <= ldate
      order by fdate, ldate desc
      limit 1;
  if ld < dt then
    if fd is NULL then
      insert ignore into wertedates
        (werteindizesID, serverID, sectionID, teststepID, teststepdetailsID, accessID, fdate, ldate)
        values (wid, sid, sec, tst, det, aid, dt, dt); 
    else
      update wertedates set ldate = dt
        where werteindizesID = wid and fdate = fd and ldate <= dt;
    end if;
    set fd = NULL;
    set ld = '0000-00-00';
    select fdate, ldate into fd, ld from teststepdates
        where serverID = sid and sectionID = sec and teststepID = tst and accessID = aid
          and fdate <= dt and dt - interval 1 day <= ldate
        order by fdate, ldate desc
        limit 1;
    if ld < dt then
      if fd is NULL then
        insert ignore into teststepdates
          (serverID, sectionID, teststepID, accessID, fdate, ldate)
          values (sid, sec, tst, aid, dt, dt);
      else
        update teststepdates set ldate = dt
          where serverID = sid and sectionID = sec and teststepID = tst and accessID = aid
            and fdate = fd and ldate <= dt;
      end if;
      set fd = NULL;
      set ld = '0000-00-00';
      select fdate, ldate into fd, ld from sectiondates
          where serverID = sid and sectionID = sec and accessID = aid
            and fdate <= dt and dt - interval 1 day <= ldate
          order by fdate, ldate desc
          limit 1;
      if ld < dt then
        if fd is NULL then
          insert ignore into sectiondates (serverID, sectionID, accessID, fdate, ldate)
            values (sid, sec, aid, dt, dt);
        else
          update sectiondates set ldate = dt
            where serverID = sid and sectionID = sec and accessID = aid
              and fdate = fd and ldate <= dt;
        end if;
        set fd = NULL;
        set ld = '0000-00-00';
        select fdate, ldate into fd, ld from serverdates
            where serverID = sid and accessID = aid
              and fdate <= dt and dt - interval 1 day <= ldate
            order by fdate, ldate desc
            limit 1;
        if ld < dt then
          if fd is NULL then
            insert ignore into serverdates (serverID, accessID, fdate, ldate)
            values (sid, aid, dt, dt);
          else
            update serverdates set ldate = dt
              where serverID = sid and accessID = aid
                and fdate = fd and ldate <= dt;
          end if;
        end if;
      end if;
    end if;
  end if;
end//

GRANT EXECUTE on PROCEDURE wzeiten to logging@'localhost'//
GRANT update (ldate) on `logging`.`serverdates` TO 'logging'@'localhost'//
GRANT update (ldate) on `logging`.`sectiondates` TO 'logging'@'localhost'//
GRANT update (ldate) on `logging`.`teststepdates` TO 'logging'@'localhost'//
GRANT update (ldate) on `logging`.`wertedates` TO 'logging'@'localhost'//
